Docutils AST Writer
===================

`docutils-ast-writer` is AST writer of Docutils.

Installation
------------

From Pypi::

  pip install docutils-ast-writer

  or

  easy_install docutils-ast-writer

Manual Installation::

  git clone https://github.com/jimo1001/docutils-ast-writer.git
  cd docutils-ast-writer
  python setup.py install


Usage
-----

::

   rst2ast [options] [<source> [<destination>]]

